searchData={"items":[{"type":"module","title":"APNSToken","doc":"Tiny APNs token generator","ref":"APNSToken.html"},{"type":"function","title":"APNSToken.generate/1","doc":"Returns a JWT token suitable for APNs.","ref":"APNSToken.html#generate/1"},{"type":"function","title":"Options - APNSToken.generate/1","doc":"* `:jwk` - JWK from PEM-encoded token signing key downloaded from [developer.apple.com](https://developer.apple.com/account/resources/keys/list)\n  * `:kid` - The 10-character Key ID you obtained from your developer account; see [Get a key identifier.](https://developer.apple.com/help/account/manage-keys/get-a-key-identifier)\n  * `:iss` - The issuer key, the value for which is the 10-character Team ID you use for developing your company’s apps. Obtain this value from your developer account.\n  * `:cache` - an ETS table name to be used as cache. For example: `:ets.new(:your_name, [:named_table, :public, read_concurrency: true])`\n\nPlease see [Obtain an encryption key and key ID from Apple](https://developer.apple.com/documentation/usernotifications/establishing-a-token-based-connection-to-apns#Obtain-an-encryption-key-and-key-ID-from-Apple) for more details.","ref":"APNSToken.html#generate/1-options"},{"type":"extras","title":"APNSToken","doc":"# APNSToken\n\n[![Documentation badge](https://img.shields.io/badge/Documentation-ff69b4)](https://hexdocs.pm/apns_token)\n[![Hex.pm badge](https://img.shields.io/badge/Package%20on%20hex.pm-informational)](https://hex.pm/packages/apns_token)\n\nTiny library to generate and cache [APNs](https://developer.apple.com/documentation/usernotifications) (Apple Push Notification service) [tokens.](https://developer.apple.com/documentation/usernotifications/establishing-a-token-based-connection-to-apns)\n\nCan be used with [Finch](https://github.com/sneako/finch) for a full-featured APNs client. Note however, that APNs doesn't support authentication tokens from multiple developer accounts over a single connection.","ref":"readme.html"},{"type":"extras","title":"Installation - APNSToken","doc":"```elixir\ndefp deps do\n  [\n    {:apns_token, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - APNSToken","doc":"```elixir\nMix.install([:apns_token, :jason, :finch])\n\nFinch.start_link(\n  name: MyApp.Finch,\n  pools: %{\n    \"api.development.push.apple.com\" => [protocol: :http2],\n    \"api.push.apple.com\" => [protocol: :http2]\n  }\n)\n\n:ets.new(:apns_jwt_cache, [:named_table, :public, read_concurrency: true])\n\n# NOTE: kid, key_id, and team_id can be stored in app env on startup, e.g. in your app's config/runtime.exs\n\n# Auth Key from .p8 file from Apple\njwk =\n  JOSE.JWK.from_pem(\"\"\"\n  -----BEGIN PRIVATE KEY-----\n  MIGHAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBG0wawIBAQQgEbVzfPnZPxfAyxqE\n  ZV05laAoJAl+/6Xt2O4mOB611sOhRANCAASgFTKjwJAAU95g++/vzKWHkzAVmNMI\n  tB5vTjZOOIwnEb70MsWZFIyUFD1P9Gwstz4+akHX7vI8BH6hHmBmfeQl\n  -----END PRIVATE KEY-----\n  \"\"\")\n\n# Key ID from developer account (Certificates, Identifiers & Profiles -> Keys)\nkey_id = \"ABC123DEFG\"\n# Team ID from developer account (View Account -> Membership)\nteam_id = \"DEF123GHIJ\"\n\ntoken = APNSToken.generate(jwk: jwk, kid: key_id, iss: team_id, cache: :apns_jwt_cache)\n\ndevice_id = \"11aa01229f15f0f0c52029d8cf8cd0aeaf2365fe4cebc4af26cd6d76b7919ef7\"\ntopic = \"com.sideshow.Apns2\"\n\nurl = \"https://api.development.push.apple.com/3/device/\" <> device_id\n\nheaders = [\n  {\"authorization\", \"bearer \" <> token},\n  {\"apns-topic\", topic},\n  {\"apns-push-type\", \"alert\"}\n]\n\nbody = Jason.encode_to_iodata!(%{\"aps\" => %{\"alert\" => \"Hello\"}})\nreq = Finch.build(:post, url, headers, body)\nFinch.request(req, MyApp.Finch)\n```","ref":"readme.html#usage"},{"type":"extras","title":"v0.1.0 (2024-07-10)","doc":"# v0.1.0 (2024-07-10)\n\n- initial release","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}